=======
Credits
=======

Development Lead
----------------

* Ehlo Onion <onionmx@lists.immerda.ch>
* George Kargiotakis <kargig@void.gr>
* John Paraskevopoulos <ioparaskev@gmail.com>

Contributors
------------

* George Kargiotakis <kargig@void.gr>
* John Paraskevopoulos <ioparaskev@gmail.com>
